@@ -1,5 +1,6 @@
 import asyncio
 import socket
+import ssl
 from urllib.parse import urlparse
 
 from .exceptions import *  # pylint: disable=wildcard-import
@@ -10,8 +11,8 @@ from .version import __packagename__
 
 
 async def connect(host='localhost', port=None, login='guest', password='guest',
-            virtualhost='/', ssl=None, login_method='AMQPLAIN', insist=False,
-            protocol_factory=AmqpProtocol, *, loop=None, **kwargs):
+            virtualhost='/', ssl=None, login_method='PLAIN', insist=False,  # pylint: disable=redefined-outer-name
+            protocol_factory=AmqpProtocol, **kwargs):
     """Convenient method to connect to an AMQP broker
 
         @host:          the host to connect to
@@ -25,15 +26,12 @@ async def connect(host='localhost', port=None, login='guest', password='guest',
         @insist:        Insist on connecting to a server
         @protocol_factory:
                         Factory to use, if you need to subclass AmqpProtocol
-        @loop:          Set the event loop to use
 
         @kwargs:        Arguments to be given to the protocol_factory instance
 
         Returns:        a tuple (transport, protocol) of an AmqpProtocol instance
     """
-    if loop is None:
-        loop = asyncio.get_event_loop()
-    factory = lambda: protocol_factory(loop=loop, **kwargs)
+    factory = lambda: protocol_factory(**kwargs)  # pylint: disable=unnecessary-lambda
 
     create_connection_kwargs = {}
 
@@ -46,7 +44,7 @@ async def connect(host='localhost', port=None, login='guest', password='guest',
         else:
             port = 5672
 
-    transport, protocol = await loop.create_connection(
+    transport, protocol = await asyncio.get_running_loop().create_connection(
         factory, host, port, **create_connection_kwargs
     )
 
@@ -69,7 +67,7 @@ async def connect(host='localhost', port=None, login='guest', password='guest',
 
 
 async def from_url(
-        url, login_method='AMQPLAIN', insist=False, protocol_factory=AmqpProtocol, **kwargs):
+        url, login_method='PLAIN', insist=False, protocol_factory=AmqpProtocol, **kwargs):
     """ Connect to the AMQP using a single url parameter and return the client.
 
         For instance:
@@ -79,7 +77,6 @@ async def from_url(
         @insist:        Insist on connecting to a server
         @protocol_factory:
                         Factory to use, if you need to subclass AmqpProtocol
-        @loop:          optionally set the event loop to use.
 
         @kwargs:        Arguments to be given to the protocol_factory instance
 
@@ -88,7 +85,10 @@ async def from_url(
     url = urlparse(url)
 
     if url.scheme not in ('amqp', 'amqps'):
-        raise ValueError('Invalid protocol %s, valid protocols are amqp or amqps' % url.scheme)
+        raise ValueError(f'Invalid protocol {url.scheme}, valid protocols are amqp or amqps')
+
+    if url.scheme == 'amqps' and not kwargs.get('ssl'):
+        kwargs['ssl'] = ssl.create_default_context()
 
     transport, protocol = await connect(
         host=url.hostname or 'localhost',
