@@ -5,9 +5,9 @@
 import asyncio
 import logging
 
+import pamqp.commands
 import pamqp.frame
 import pamqp.heartbeat
-import pamqp.specification
 
 from . import channel as amqp_channel
 from . import constants as amqp_constants
@@ -61,12 +61,10 @@ class AmqpProtocol(asyncio.StreamReaderProtocol):
                             but may reject very large frames if it cannot allocate resources for them.
             heartbeat: int, the delay, in seconds, of the connection heartbeat that the server wants.
                             Zero means the server does not want a heartbeat.
-            loop: Asyncio.Eventloop: specify the eventloop to use.
             client_properties: dict, client-props to tune the client identification
         """
-        self._loop = kwargs.get('loop') or asyncio.get_event_loop()
-        self._reader = asyncio.StreamReader(loop=self._loop)
-        super().__init__(self._reader, loop=self._loop)
+        self._reader = asyncio.StreamReader()
+        super().__init__(self._reader)
         self._on_error_callback = kwargs.get('on_error')
 
         self.client_properties = kwargs.get('client_properties', {})
@@ -78,9 +76,9 @@ class AmqpProtocol(asyncio.StreamReaderProtocol):
         if 'heartbeat' in kwargs:
             self.connection_tunning['heartbeat'] = kwargs.get('heartbeat')
 
-        self.connecting = asyncio.Future(loop=self._loop)
-        self.connection_closed = asyncio.Event(loop=self._loop)
-        self.stop_now = asyncio.Future(loop=self._loop)
+        self.connecting = asyncio.Future()
+        self.connection_closed = asyncio.Event()
+        self.stop_now = asyncio.Event()
         self.state = CONNECTING
         self.version_major = None
         self.version_minor = None
@@ -89,20 +87,21 @@ class AmqpProtocol(asyncio.StreamReaderProtocol):
         self.server_locales = None
         self.worker = None
         self.server_heartbeat = None
-        self._heartbeat_timer_recv = None
-        self._heartbeat_timer_send = None
-        self._heartbeat_trigger_send = asyncio.Event(loop=self._loop)
-        self._heartbeat_worker = None
+        self._heartbeat_last_recv = None
+        self._heartbeat_last_send = None
+        self._heartbeat_recv_worker = None
+        self._heartbeat_send_worker = None
         self.channels = {}
         self.server_frame_max = None
         self.server_channel_max = None
         self.channels_ids_ceil = 0
         self.channels_ids_free = set()
-        self._drain_lock = asyncio.Lock(loop=self._loop)
+        self._drain_lock = asyncio.Lock()
 
     def connection_made(self, transport):
         super().connection_made(transport)
-        self._stream_writer = _StreamWriter(transport, self, self._stream_reader, self._loop)
+        self._stream_writer = _StreamWriter(transport, self, self._stream_reader,
+                                            loop=asyncio.get_running_loop())
 
     def eof_received(self):
         super().eof_received()
@@ -159,7 +158,7 @@ class AmqpProtocol(asyncio.StreamReaderProtocol):
         """Close connection (and all channels)"""
         await self.ensure_open()
         self.state = CLOSING
-        request = pamqp.specification.Connection.Close(
+        request = pamqp.commands.Connection.Close(
             reply_code=0,
             reply_text='',
             class_id=0,
@@ -171,16 +170,13 @@ class AmqpProtocol(asyncio.StreamReaderProtocol):
             await self.wait_closed(timeout=timeout)
 
     async def wait_closed(self, timeout=None):
-        await asyncio.wait_for(self.connection_closed.wait(), timeout=timeout, loop=self._loop)
-        if self._heartbeat_worker is not None:
+        await asyncio.wait_for(self.connection_closed.wait(), timeout=timeout)
+        if self._heartbeat_send_worker is not None:
             try:
-                await asyncio.wait_for(self._heartbeat_worker, timeout=timeout, loop=self._loop)
+                await asyncio.wait_for(self._heartbeat_send_worker, timeout=timeout)
             except asyncio.CancelledError:
                 pass
 
-    async def close_ok(self, frame):
-        self._stream_writer.close()
-
     async def start_connection(self, host, port, login, password, virtualhost, ssl=False,
             login_method='PLAIN', insist=False):
         """Initiate a connection at the protocol level
@@ -188,7 +184,7 @@ class AmqpProtocol(asyncio.StreamReaderProtocol):
         """
 
         if login_method != 'PLAIN':
-            logger.warning('only PLAIN login_method is supported, falling back to AMQPLAIN')
+            logger.warning('login_method %s is not supported, falling back to PLAIN', login_method)
 
         self._stream_writer.write(amqp_constants.PROTOCOL_HEADER)
 
@@ -242,7 +238,7 @@ class AmqpProtocol(asyncio.StreamReaderProtocol):
 
         await self.ensure_open()
         # for now, we read server's responses asynchronously
-        self.worker = asyncio.ensure_future(self.run(), loop=self._loop)
+        self.worker = asyncio.ensure_future(self.run())
 
     async def get_frame(self):
         """Read the frame, and only decode its header
@@ -254,11 +250,11 @@ class AmqpProtocol(asyncio.StreamReaderProtocol):
         """Dispatch the received frame to the corresponding handler"""
 
         method_dispatch = {
-            pamqp.specification.Connection.Close.name: self.server_close,
-            pamqp.specification.Connection.CloseOk.name: self.close_ok,
-            pamqp.specification.Connection.Tune.name: self.tune,
-            pamqp.specification.Connection.Start.name: self.start,
-            pamqp.specification.Connection.OpenOk.name: self.open_ok,
+            pamqp.commands.Connection.Close.name: self.server_close,
+            pamqp.commands.Connection.CloseOk.name: self.close_ok,
+            pamqp.commands.Connection.Tune.name: self.tune,
+            pamqp.commands.Connection.Start.name: self.start,
+            pamqp.commands.Connection.OpenOk.name: self.open_ok,
         }
         if frame_channel is None and frame is None:
             frame_channel, frame = await self.get_frame()
@@ -303,7 +299,7 @@ class AmqpProtocol(asyncio.StreamReaderProtocol):
 
         if self._on_error_callback:
             if asyncio.iscoroutinefunction(self._on_error_callback):
-                asyncio.ensure_future(self._on_error_callback(exception), loop=self._loop)
+                asyncio.ensure_future(self._on_error_callback(exception))
             else:
                 self._on_error_callback(exceptions.ChannelClosed(exception))
 
@@ -311,12 +307,12 @@ class AmqpProtocol(asyncio.StreamReaderProtocol):
             channel.connection_closed(reply_code, reply_text, exception)
 
     async def run(self):
-        while not self.stop_now.done():
+        while not self.stop_now.is_set():
             try:
                 await self.dispatch_frame()
             except exceptions.AmqpClosedConnection as exc:
                 logger.info("Close connection")
-                self.stop_now.set_result(None)
+                self.stop_now.set()
 
                 self._close_channels(exception=exc)
             except Exception:  # pylint: disable=broad-except
@@ -329,7 +325,7 @@ class AmqpProtocol(asyncio.StreamReaderProtocol):
         the rest of the AmqpProtocol class.  This is kept around for backwards
         compatibility purposes only.
         """
-        await self.stop_now
+        await self.stop_now.wait()
 
     async def send_heartbeat(self):
         """Sends an heartbeat message.
@@ -339,48 +335,58 @@ class AmqpProtocol(asyncio.StreamReaderProtocol):
         request = pamqp.heartbeat.Heartbeat()
         await self._write_frame(0, request)
 
-    def _heartbeat_timer_recv_timeout(self):
+    def _heartbeat_timer_recv_reset(self):
+        if self.server_heartbeat is None or self.server_heartbeat == 0:
+            return
+        self._heartbeat_last_recv = asyncio.get_running_loop().time()
+        if self._heartbeat_recv_worker is None:
+            self._heartbeat_recv_worker = asyncio.ensure_future(self._heartbeat_recv())
+
+    def _heartbeat_timer_send_reset(self):
+        if self.server_heartbeat is None or self.server_heartbeat == 0:
+            return
+        self._heartbeat_last_send = asyncio.get_running_loop().time()
+        if self._heartbeat_send_worker is None:
+            self._heartbeat_send_worker = asyncio.ensure_future(self._heartbeat_send())
+
+    def _heartbeat_stop(self):
+        self.server_heartbeat = None
+        if self._heartbeat_recv_worker is not None:
+            self._heartbeat_recv_worker.cancel()
+        if self._heartbeat_send_worker is not None:
+            self._heartbeat_send_worker.cancel()
+
+    async def _heartbeat_recv(self):
         # 4.2.7 If a peer detects no incoming traffic (i.e. received octets) for
         # two heartbeat intervals or longer, it should close the connection
         # without following the Connection.Close/Close-Ok handshaking, and log
         # an error.
         # TODO(rcardona) raise a "timeout" exception somewhere
-        self._stream_writer.close()
+        now = asyncio.get_running_loop().time()
+        time_since_last_recv = now - self._heartbeat_last_recv
 
-    def _heartbeat_timer_recv_reset(self):
-        if self.server_heartbeat is None:
-            return
-        if self._heartbeat_timer_recv is not None:
-            self._heartbeat_timer_recv.cancel()
-        self._heartbeat_timer_recv = self._loop.call_later(
-            self.server_heartbeat * 2,
-            self._heartbeat_timer_recv_timeout)
-
-    def _heartbeat_timer_send_reset(self):
-        if self.server_heartbeat is None:
-            return
-        if self._heartbeat_timer_send is not None:
-            self._heartbeat_timer_send.cancel()
-        self._heartbeat_timer_send = self._loop.call_later(
-            self.server_heartbeat,
-            self._heartbeat_trigger_send.set)
-        if self._heartbeat_worker is None:
-            self._heartbeat_worker = asyncio.ensure_future(self._heartbeat(), loop=self._loop)
-
-    def _heartbeat_stop(self):
-        self.server_heartbeat = None
-        if self._heartbeat_timer_recv is not None:
-            self._heartbeat_timer_recv.cancel()
-        if self._heartbeat_timer_send is not None:
-            self._heartbeat_timer_send.cancel()
-        if self._heartbeat_worker is not None:
-            self._heartbeat_worker.cancel()
-
-    async def _heartbeat(self):
         while self.state != CLOSED:
-            await self._heartbeat_trigger_send.wait()
-            self._heartbeat_trigger_send.clear()
-            await self.send_heartbeat()
+            sleep_for = self.server_heartbeat * 2 - time_since_last_recv
+            await asyncio.sleep(sleep_for)
+
+            now = asyncio.get_running_loop().time()
+            time_since_last_recv = now - self._heartbeat_last_recv
+            if time_since_last_recv >= self.server_heartbeat * 2:
+                self._stream_writer.close()
+
+    async def _heartbeat_send(self):
+        now = asyncio.get_running_loop().time()
+        time_since_last_send = now - self._heartbeat_last_send
+
+        while self.state != CLOSED:
+            sleep_for = self.server_heartbeat - time_since_last_send
+            await asyncio.sleep(sleep_for)
+
+            now = asyncio.get_running_loop().time()
+            time_since_last_send = now - self._heartbeat_last_send
+            if time_since_last_send >= self.server_heartbeat:
+                await self.send_heartbeat()
+                time_since_last_send = now - self._heartbeat_last_send
 
     # Amqp specific methods
     async def start(self, frame):
@@ -393,9 +399,9 @@ class AmqpProtocol(asyncio.StreamReaderProtocol):
 
     async def start_ok(self, client_properties, mechanism, auth, locale):
         def credentials():
-            return '\0{LOGIN}\0{PASSWORD}'.format(**auth)
+            return f'\0{auth["LOGIN"]}\0{auth["PASSWORD"]}'
 
-        request = pamqp.specification.Connection.StartOk(
+        request = pamqp.commands.Connection.StartOk(
             client_properties=client_properties,
             mechanism=mechanism,
             locale=locale,
@@ -403,6 +409,11 @@ class AmqpProtocol(asyncio.StreamReaderProtocol):
         )
         await self._write_frame(0, request)
 
+    async def close_ok(self, frame):
+        """In response to server close confirmation"""
+        self.stop_now.set()
+        self._stream_writer.close()
+
     async def server_close(self, frame):
         """The server is closing the connection"""
         self.state = CLOSING
@@ -414,10 +425,12 @@ class AmqpProtocol(asyncio.StreamReaderProtocol):
             reply_text, reply_code, class_id, method_id)
         self._close_channels(reply_code, reply_text)
         await self._close_ok()
+        self.stop_now.set()
         self._stream_writer.close()
 
     async def _close_ok(self):
-        request = pamqp.specification.Connection.CloseOk()
+        """Send client close confirmation"""
+        request = pamqp.commands.Connection.CloseOk()
         await self._write_frame(0, request)
 
     async def tune(self, frame):
@@ -426,7 +439,7 @@ class AmqpProtocol(asyncio.StreamReaderProtocol):
         self.server_heartbeat = frame.heartbeat
 
     async def tune_ok(self, channel_max, frame_max, heartbeat):
-        request = pamqp.specification.Connection.TuneOk(
+        request = pamqp.commands.Connection.TuneOk(
             channel_max, frame_max, heartbeat
         )
         await self._write_frame(0, request)
@@ -436,7 +449,7 @@ class AmqpProtocol(asyncio.StreamReaderProtocol):
 
     async def open(self, virtual_host, capabilities='', insist=False):
         """Open connection to virtual host."""
-        request = pamqp.specification.Connection.Open(
+        request = pamqp.commands.Connection.Open(
             virtual_host, capabilities, insist
         )
         await self._write_frame(0, request)
@@ -456,11 +469,11 @@ class AmqpProtocol(asyncio.StreamReaderProtocol):
         await self.ensure_open()
         try:
             channel_id = self.channels_ids_free.pop()
-        except KeyError:
+        except KeyError as ex:
             assert self.server_channel_max is not None, 'connection channel-max tuning not performed'
             # channel-max = 0 means no limit
             if self.server_channel_max and self.channels_ids_ceil > self.server_channel_max:
-                raise exceptions.NoChannelAvailable()
+                raise exceptions.NoChannelAvailable() from ex
             self.channels_ids_ceil += 1
             channel_id = self.channels_ids_ceil
         channel = self.CHANNEL_FACTORY(self, channel_id, **kwargs)
