@@ -24,7 +24,7 @@ class ConnectionLostTestCase(testcase.RabbitTestCaseMixin, asynctest.TestCase):
         self.assertEqual(amqp.state, OPEN)
         self.assertTrue(channel.is_open)
         amqp._stream_reader._transport.close()  # this should have the same effect as the tcp connection being lost
-        await asyncio.wait_for(amqp.worker, 1, loop=self.loop)
+        await asyncio.wait_for(amqp.worker, 1)
         self.assertEqual(amqp.state, CLOSED)
         self.assertFalse(channel.is_open)
         self.assertTrue(self.callback_called)
