@@ -1,4 +1,3 @@
-
 import asyncio
 import asynctest
 
@@ -14,7 +13,7 @@ class ConsumeTestCase(testcase.RabbitTestCaseMixin, asynctest.TestCase):
 
     def setUp(self):
         super().setUp()
-        self.consume_future = asyncio.Future(loop=self.loop)
+        self.consume_future = asyncio.Future()
 
     async def callback(self, channel, body, envelope, properties):
         self.consume_future.set_result((body, envelope, properties))
@@ -22,7 +21,7 @@ class ConsumeTestCase(testcase.RabbitTestCaseMixin, asynctest.TestCase):
     async def get_callback_result(self):
         await self.consume_future
         result = self.consume_future.result()
-        self.consume_future = asyncio.Future(loop=self.loop)
+        self.consume_future = asyncio.Future()
         return result
 
     async def test_consume(self):
@@ -80,12 +79,12 @@ class ConsumeTestCase(testcase.RabbitTestCaseMixin, asynctest.TestCase):
         # get a different channel
         channel = await self.create_channel()
 
-        q1_future = asyncio.Future(loop=self.loop)
+        q1_future = asyncio.Future()
 
         async def q1_callback(channel, body, envelope, properties):
             q1_future.set_result((body, envelope, properties))
 
-        q2_future = asyncio.Future(loop=self.loop)
+        q2_future = asyncio.Future()
 
         async def q2_callback(channel, body, envelope, properties):
             q2_future.set_result((body, envelope, properties))
@@ -115,6 +114,10 @@ class ConsumeTestCase(testcase.RabbitTestCaseMixin, asynctest.TestCase):
         self.assertEqual(b"coucou2", body2)
         self.assertIsInstance(properties2, Properties)
 
+        # close consuming
+        await asyncio.gather(self.channel.basic_cancel(ctag_q1),
+                             self.channel.basic_cancel(ctag_q2))
+
     async def test_duplicate_consumer_tag(self):
         await self.channel.queue_declare("q1", exclusive=True, no_wait=False)
         await self.channel.queue_declare("q2", exclusive=True, no_wait=False)
@@ -137,7 +140,7 @@ class ConsumeTestCase(testcase.RabbitTestCaseMixin, asynctest.TestCase):
         # publish
         await channel.publish("coucou", "e", routing_key='',)
 
-        sync_future = asyncio.Future(loop=self.loop)
+        sync_future = asyncio.Future()
 
         async def callback(channel, body, envelope, properties):
             self.assertTrue(sync_future.done())
@@ -156,12 +159,12 @@ class ConsumeTestCase(testcase.RabbitTestCaseMixin, asynctest.TestCase):
         # get a different channel
         channel = await self.create_channel()
 
-        q1_future = asyncio.Future(loop=self.loop)
+        q1_future = asyncio.Future()
 
         async def q1_callback(channel, body, envelope, properties):
             q1_future.set_result((body, envelope, properties))
 
-        q2_future = asyncio.Future(loop=self.loop)
+        q2_future = asyncio.Future()
 
         async def q2_callback(channel, body, envelope, properties):
             q2_future.set_result((body, envelope, properties))
