@@ -17,11 +17,13 @@ class HeartbeatTestCase(testcase.RabbitTestCaseMixin, asynctest.TestCase):
         with mock.patch.object(
                 self.amqp, 'send_heartbeat', wraps=self.amqp.send_heartbeat
                 ) as send_heartbeat:
-            # reset both timers to 1) make them 'see' the new heartbeat value
+            # reset both timer/task to 1) make them 'see' the new heartbeat value
             # 2) so that the mock is actually called back from the main loop
             self.amqp.server_heartbeat = 1
-            self.amqp._heartbeat_timer_send_reset()
-            self.amqp._heartbeat_timer_recv_reset()
+            self.amqp._heartbeat_send_worker.cancel()
+            self.amqp._heartbeat_send_worker = asyncio.ensure_future(self.amqp._heartbeat_send())
+            self.amqp._heartbeat_recv_worker.cancel()
+            self.amqp._heartbeat_recv_worker = asyncio.ensure_future(self.amqp._heartbeat_recv())
 
             await asyncio.sleep(1.001)
             send_heartbeat.assert_called_once_with()
