@@ -15,14 +15,13 @@ def fib(n):
         return fib(n-1) + fib(n-2)
 
 
-@asyncio.coroutine
-def on_request(channel, body, envelope, properties):
+async def on_request(channel, body, envelope, properties):
     n = int(body)
 
     print(" [.] fib(%s)" % n)
     response = fib(n)
 
-    yield from channel.basic_publish(
+    await channel.basic_publish(
         payload=str(response),
         exchange_name='',
         routing_key=properties.reply_to,
@@ -31,24 +30,21 @@ def on_request(channel, body, envelope, properties):
         },
     )
 
-    yield from channel.basic_client_ack(delivery_tag=envelope.delivery_tag)
-    
+    await channel.basic_client_ack(delivery_tag=envelope.delivery_tag)
 
-@asyncio.coroutine
-def rpc_server():
 
-    transport, protocol = yield from aioamqp.connect()
+async def rpc_server():
 
-    channel = yield from protocol.channel()
+    transport, protocol = await aioamqp.connect()
 
-    yield from channel.queue_declare(queue_name='rpc_queue')
-    yield from channel.basic_qos(prefetch_count=1, prefetch_size=0, connection_global=False)
-    yield from channel.basic_consume(on_request, queue_name='rpc_queue')
+    channel = await protocol.channel()
+
+    await channel.queue_declare(queue_name='rpc_queue')
+    await channel.basic_qos(prefetch_count=1, prefetch_size=0, connection_global=False)
+    await channel.basic_consume(on_request, queue_name='rpc_queue')
     print(" [x] Awaiting RPC requests")
 
 
 event_loop = asyncio.get_event_loop()
 event_loop.run_until_complete(rpc_server())
 event_loop.run_forever()
-
-
